AgentWithVersionResponse class final

Annotations
  • @JsonSerializable.new()

Constructors

AgentWithVersionResponse({required String id, required String name, required String? description, required AgentStatus status, required String? providerId, String? model, required String instructions, String? systemPrompt, required Map<String, Object> config, Iterable? tools, String? templateType, required String createdAt, required String? updatedAt, required String? lastUsedAt})
Returns a new AgentWithVersionResponse instance.
const
AgentWithVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

config Map<String, Object>
final
createdAt String
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
instructions String
final
lastUsedAt String?
final
model String?
final
name String
final
providerId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AgentStatus
final
systemPrompt String?
final
templateType String?
final
tools Iterable?
One of types:
final
updatedAt String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override