UserMessageV4 class final

Annotations
  • @JsonSerializable.new()

Constructors

UserMessageV4({String? id, required String role, required String content, List<TextPartV4>? parts, List<Map<String, Object>>? annotations})
Returns a new UserMessageV4 instance.
const
UserMessageV4.fromJson(Map<String, dynamic> json)
factory

Properties

annotations List<Map<String, Object>>?
final
content String
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
parts List<TextPartV4>?
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override